/* eslint-env jest */

import C360InputRadio from '../input-radio';
import * as utils from '../../../../../.jest/utils';
customElements.define('c360-input-radio', C360InputRadio);

describe('c360-input-radio', () => {
  afterEach(() => {
    // The jsdom instance is shared across test cases in a single file so reset the DOM
    while (document.body.firstChild) {
      document.body.removeChild(document.body.firstChild);
    }
  });

  it('should contain size attribute as large by default', async () => {
    const element = utils.renderIntoBody(`<c360-input-radio>Radio Label</c360-input-radio>`);
    expect(element).toHaveAttribute('size', 'large');
  });

  it('should not be checked by default', async () => {
    const element = utils.renderIntoBody(`<c360-input-radio>Radio Label</c360-input-radio>`);
    const radio = element.shadowRoot.querySelector('[part~="radio"]');
    expect(element).not.toHaveAttribute('checked');
    expect(radio).not.toHaveAttribute('checked');
  });

  it('should contain checked attribute', async () => {
    const element = utils.renderIntoBody(`<c360-input-radio checked>Radio Label</c360-input-radio>`);
    const radio = element.shadowRoot.querySelector('[part~="radio"]');
    expect(element).toHaveAttribute('checked');
    expect(radio).toHaveAttribute('checked');
  });

  it('should contain disabled attribute', async () => {
    const element = utils.renderIntoBody(`<c360-input-radio disabled>Radio Label
      </c360-input-radio>`);
    const radio = element.shadowRoot.querySelector('[part~="radio"]');
    expect(element).toHaveAttribute('disabled');
    expect(radio).toHaveAttribute('disabled');
  });

  it('should contain checked & disabled attributes', async () => {
    const element = utils.renderIntoBody(`<c360-input-radio checked disabled>Radio Label
      </c360-input-radio>`);
    const radio = element.shadowRoot.querySelector('[part~="radio"]');
    expect(element).toHaveAttribute('checked');
    expect(element).toHaveAttribute('disabled');
    expect(radio).toHaveAttribute('checked');
    expect(radio).toHaveAttribute('disabled');
  });

  it('should contain required & error attributes', async () => {
    const element = utils.renderIntoBody(`<c360-input-radio required error>Radio Label
      </c360-input-radio>`);
    const radio = element.shadowRoot.querySelector('[part~="radio"]');
    expect(element).toHaveAttribute('required');
    expect(element).toHaveAttribute('error');
    expect(radio).toHaveAttribute('required');
    expect(radio).toHaveAttribute('error');
  });

  it('is accessible', async () => {
    const element = utils.renderIntoBody(`<c360-input-radio>Radio label
      </c360-input-radio>`);
    return Promise.resolve().then(() => {
      expect(element).toBeAccessible();
    });
  });
});
